{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Neurons example, no slopes\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {},
   "outputs": [],
   "source": [
    "from importlib import reload\n",
    "\n",
    "from bayes_window import visualization\n",
    "from bayes_window import workflow, models, BayesWindow, BayesConditions, BayesRegression\n",
    "from bayes_window.generative_models import generate_fake_spikes"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Make fake data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "lines_to_next_cell": 2
   },
   "outputs": [],
   "source": [
    "df, df_monster, index_cols, firing_rates = generate_fake_spikes(n_trials=5,\n",
    "                                                                n_neurons=3,\n",
    "                                                                n_mice=4,\n",
    "                                                                dur=7,\n",
    "                                                               mouse_response_slope=16)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Quick workflow"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-e133797b0dba4e9fb266d0013d4dce2a\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-e133797b0dba4e9fb266d0013d4dce2a\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-e133797b0dba4e9fb266d0013d4dce2a\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-83c357cbb429027bd329fe7eaea3c9cc\"}, \"facet\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"spec\": {\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}, \"title\": \"isi\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-83c357cbb429027bd329fe7eaea3c9cc\": [{\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "bw=workflow.BayesWindow(df,y='isi',treatment='stim', condition='neuron', group='mouse',)\n",
    "bw.plot(x='stim').facet('neuron')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "TODO this default is fishy"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-c338345905c64b3abd8168a30680176b\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-c338345905c64b3abd8168a30680176b\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-c338345905c64b3abd8168a30680176b\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}], \"data\": {\"name\": \"data-83c357cbb429027bd329fe7eaea3c9cc\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-83c357cbb429027bd329fe7eaea3c9cc\": [{\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "bw.plot()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-b2562f0a4250440ab630343f1160c10b\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-b2562f0a4250440ab630343f1160c10b\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-b2562f0a4250440ab630343f1160c10b\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}, \"title\": \"isi\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"mouse\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}], \"data\": {\"name\": \"data-83c357cbb429027bd329fe7eaea3c9cc\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-83c357cbb429027bd329fe7eaea3c9cc\": [{\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2}, {\"stim\": 0, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 1, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 0, \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 1, \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 2, \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2}, {\"stim\": 1, \"neuron\": 2, \"mouse\": 3, \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "bw.plot(x='stim', detail='neuron', color='mouse:N')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Is this bc chart_p and chart_d traded places?"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 43,
   "metadata": {
    "lines_to_next_cell": 2
   },
   "outputs": [],
   "source": [
    "bw=BayesConditions(df=df,y='isi',treatment='stim', condition='neuron', group='mouse')\n",
    "\n",
    "bw.fit(model=models.model_single, );"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "TODO data is fine, posterior is not\n",
    "\n",
    "TODO Need saner facet call"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 44,
   "metadata": {
    "lines_to_next_cell": 2
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-ff2a13cce25c4f209af5488cd007d507\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-ff2a13cce25c4f209af5488cd007d507\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-ff2a13cce25c4f209af5488cd007d507\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 160, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse m0bayes  \", \"transform\": [{\"filter\": \"(datum['mouse'] === 'm0bayes')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 160, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse m1bayes  \", \"transform\": [{\"filter\": \"(datum['mouse'] === 'm1bayes')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 160, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse m2bayes  \", \"transform\": [{\"filter\": \"(datum['mouse'] === 'm2bayes')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 160, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse m3bayes  \", \"transform\": [{\"filter\": \"(datum['mouse'] === 'm3bayes')\"}], \"width\": 150}], \"data\": {\"name\": \"data-5d2e11b2d5acc7bd045cdb1c4bf042d4\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-5d2e11b2d5acc7bd045cdb1c4bf042d4\": [{\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0, \"mu higher interval\": 0.041424624621868134, \"mu lower interval\": 0.01575770042836666, \"mu center interval\": 0.028734834864735603, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": 0.045403506606817245, \"sigma lower interval\": 0.007013967726379633, \"sigma center interval\": 0.020845547318458557, \"sigma_intercept_per_group higher interval\": 0.031633708626031876, \"sigma_intercept_per_group lower interval\": 0.0024695240426808596, \"sigma_intercept_per_group center interval\": 0.01361736748367548, \"sigma_obs higher interval\": 0.013520034030079842, \"sigma_obs lower interval\": 0.010449819266796112, \"sigma_obs center interval\": 0.011978302150964737, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.HConcatChart(...)"
      ]
     },
     "execution_count": 44,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "bw.plot(x='stim:O',color='neuron:N',independent_axes=False,add_data=True)#.display()\n",
    "BayesWindow.facet(bw, column='mouse')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 29,
   "metadata": {},
   "outputs": [],
   "source": [
    "df.neuron=df.neuron.astype(int)\n",
    "bw=BayesConditions(df=df,y='isi',treatment='stim', condition='neuron', group='mouse')\n",
    "\n",
    "bw.fit(model=models.model_single, )\n",
    "\n",
    "bw.plot(x='stim:O',independent_axes=False,add_data=True);"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 30,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-b97c81d0d77847ab988854dd0be04719\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-b97c81d0d77847ab988854dd0be04719\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-b97c81d0d77847ab988854dd0be04719\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-5d2e11b2d5acc7bd045cdb1c4bf042d4\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"row\": {\"type\": \"nominal\", \"field\": \"mouse\"}}, \"spec\": {\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}], \"height\": 60}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-5d2e11b2d5acc7bd045cdb1c4bf042d4\": [{\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0, \"mu higher interval\": 0.041424624621868134, \"mu lower interval\": 0.01575770042836666, \"mu center interval\": 0.028734834864735603, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": 0.045403506606817245, \"sigma lower interval\": 0.007013967726379633, \"sigma center interval\": 0.020845547318458557, \"sigma_intercept_per_group higher interval\": 0.031633708626031876, \"sigma_intercept_per_group lower interval\": 0.0024695240426808596, \"sigma_intercept_per_group center interval\": 0.01361736748367548, \"sigma_obs higher interval\": 0.013520034030079842, \"sigma_obs lower interval\": 0.010449819266796112, \"sigma_obs center interval\": 0.011978302150964737, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "#builtin facet\n",
    "bw.chart.properties(height=60).facet(column='neuron', row='mouse').display()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 37,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-4452adf8bf5e440ea4a28b1c740676ba\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-4452adf8bf5e440ea4a28b1c740676ba\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-4452adf8bf5e440ea4a28b1c740676ba\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"vconcat\": [{\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m0bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m0bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m0bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 150}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m1bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m1bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m1bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 150}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m2bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m2bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m2bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 150}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m3bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m3bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 150}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}]}], \"height\": 60, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m3bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 150}]}], \"data\": {\"name\": \"data-9018271cdbb10f31b3d54bc95d36a90c\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-9018271cdbb10f31b3d54bc95d36a90c\": [{\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0, \"mu higher interval\": 0.041424624621868134, \"mu lower interval\": 0.01575770042836666, \"mu center interval\": 0.028734834864735603, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": 0.045403506606817245, \"sigma lower interval\": 0.007013967726379633, \"sigma center interval\": 0.020845547318458557, \"sigma_intercept_per_group higher interval\": 0.031633708626031876, \"sigma_intercept_per_group lower interval\": 0.0024695240426808596, \"sigma_intercept_per_group center interval\": 0.01361736748367548, \"sigma_obs higher interval\": 0.013520034030079842, \"sigma_obs lower interval\": 0.010449819266796112, \"sigma_obs center interval\": 0.011978302150964737, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.VConcatChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# smart facet TODO\n",
    "\n",
    "BayesWindow.facet(bw,column='neuron', row='mouse',height=60).display()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 41,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-24d4f341757845e4b904d65f54468de4\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-24d4f341757845e4b904d65f54468de4\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-24d4f341757845e4b904d65f54468de4\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}], \"data\": {\"name\": \"data-5d2e11b2d5acc7bd045cdb1c4bf042d4\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-5d2e11b2d5acc7bd045cdb1c4bf042d4\": [{\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0, \"mu higher interval\": 0.041424624621868134, \"mu lower interval\": 0.01575770042836666, \"mu center interval\": 0.028734834864735603, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": 0.045403506606817245, \"sigma lower interval\": 0.007013967726379633, \"sigma center interval\": 0.020845547318458557, \"sigma_intercept_per_group higher interval\": 0.031633708626031876, \"sigma_intercept_per_group lower interval\": 0.0024695240426808596, \"sigma_intercept_per_group center interval\": 0.01361736748367548, \"sigma_obs higher interval\": 0.013520034030079842, \"sigma_obs lower interval\": 0.010449819266796112, \"sigma_obs center interval\": 0.011978302150964737, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-1aa550f7364243a590fe2be47452a7a1\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-1aa550f7364243a590fe2be47452a7a1\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-1aa550f7364243a590fe2be47452a7a1\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"vconcat\": [{\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m0bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m0bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m0bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 90}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m1bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m1bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m1bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 90}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m2bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m2bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m2bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 90}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 0 mouse m3bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '0')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 1 mouse m3bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '1')\"}], \"width\": 90}, {\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval75\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}, \"y2\": {\"field\": \"higher interval75\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}, \"title\": \"\\u0394 isi estimate\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [0, 0.06996925175189972], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.036984482809714884, 0.0879826123402963], \"zero\": false}}}}]}], \"height\": 120, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"neuron 2 mouse m3bayes\", \"transform\": [{\"filter\": \"(datum['neuron'] === '2')\"}], \"width\": 90}]}], \"data\": {\"name\": \"data-9018271cdbb10f31b3d54bc95d36a90c\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-9018271cdbb10f31b3d54bc95d36a90c\": [{\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647, \"combined_condition\": 0, \"mu higher interval\": 0.041424624621868134, \"mu lower interval\": 0.01575770042836666, \"mu center interval\": 0.028734834864735603, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": 0.045403506606817245, \"sigma lower interval\": 0.007013967726379633, \"sigma center interval\": 0.020845547318458557, \"sigma_intercept_per_group higher interval\": 0.031633708626031876, \"sigma_intercept_per_group lower interval\": 0.0024695240426808596, \"sigma_intercept_per_group center interval\": 0.01361736748367548, \"sigma_obs higher interval\": 0.013520034030079842, \"sigma_obs lower interval\": 0.010449819266796112, \"sigma_obs center interval\": 0.011978302150964737, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413, \"combined_condition\": 0, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.06996925175189972, \"lower interval\": 0.042513132095336914, \"center interval\": 0.05419785796038923, \"higher interval75\": 0.06221858039498329, \"lower interval75\": 0.047944068908691406, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287, \"combined_condition\": 1, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.03607470542192459, \"lower interval\": 0.007988104596734047, \"center interval\": 0.02099780221033143, \"higher interval75\": 0.028628915548324585, \"lower interval75\": 0.014488818123936653, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073, \"combined_condition\": 2, \"mu higher interval\": null, \"mu lower interval\": null, \"mu center interval\": null, \"mu_intercept_per_group higher interval\": null, \"mu_intercept_per_group lower interval\": null, \"mu_intercept_per_group center interval\": null, \"mu_intercept_per_group higher interval75\": null, \"mu_intercept_per_group lower interval75\": null, \"higher interval\": 0.049296148121356964, \"lower interval\": 0.022564677521586418, \"center interval\": 0.034995583539512154, \"higher interval75\": 0.042861443012952805, \"lower interval75\": 0.02842828258872032, \"sigma higher interval\": null, \"sigma lower interval\": null, \"sigma center interval\": null, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.VConcatChart(...)"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "#Full: add_data=True, independent_axes=True\n",
    "bw = BayesConditions(df=df, y='isi', treatment='stim', condition='neuron', group='mouse')\n",
    "bw.fit(model=models.model_single)\n",
    "bw.plot(x='stim:O', independent_axes=True, add_data=True).display()\n",
    "BayesWindow.facet(bw, column='neuron', row='mouse', width=90,height=120).display()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Detailed steps\n",
    "### 1. Estimate and make posterior plot"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### 2. Make data slopeplot"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-f51de1673c14497b9cf892495c58d0bb\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-f51de1673c14497b9cf892495c58d0bb\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-f51de1673c14497b9cf892495c58d0bb\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-65d03c09dcba57ce2c2350e0c0fd732c\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"mouse_code\"}}, \"spec\": {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"log_firing_rate\", \"scale\": {\"clamp\": true, \"domain\": [1.6795441592037095, 2.8435303446343494], \"zero\": false}}}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-65d03c09dcba57ce2c2350e0c0fd732c\": [{\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": 0, \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": 1, \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": 2, \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": 3, \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 20,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import altair as alt\n",
    "fig_trials=visualization.plot_data_slope_trials(\n",
    "                                                x='stim:O', y='log_firing_rate',\n",
    "                                                color='neuron:N',detail='i_trial',\n",
    "                                                base_chart=alt.Chart(df))\n",
    "\n",
    "\n",
    "#chart = visualization.AltairHack(fig_trials)\n",
    "#import types\n",
    "#fig_trials.facetz = types.MethodType(facet, fig_trials )\n",
    "#fig_trials.facetz(row='mouse')\n",
    "\n",
    "#facet=visualization.facet\n",
    "facet=fig_trials.facet\n",
    "facet(column='mouse_code')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-da03162e4b7f4d10a6af3a4d48e68919\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-da03162e4b7f4d10a6af3a4d48e68919\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-da03162e4b7f4d10a6af3a4d48e68919\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"hconcat\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"log_firing_rate\", \"scale\": {\"clamp\": true, \"domain\": [1.6795441592037095, 2.8435303446343494], \"zero\": false}}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse_code 0  \", \"transform\": [{\"filter\": \"(datum['mouse_code'] === '0')\"}], \"width\": 80}, {\"layer\": [{\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"log_firing_rate\", \"scale\": {\"clamp\": true, \"domain\": [1.6795441592037095, 2.8435303446343494], \"zero\": false}}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse_code 1  \", \"transform\": [{\"filter\": \"(datum['mouse_code'] === '1')\"}], \"width\": 80}, {\"layer\": [{\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"log_firing_rate\", \"scale\": {\"clamp\": true, \"domain\": [1.6795441592037095, 2.8435303446343494], \"zero\": false}}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse_code 2  \", \"transform\": [{\"filter\": \"(datum['mouse_code'] === '2')\"}], \"width\": 80}, {\"layer\": [{\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"log_firing_rate\", \"scale\": {\"clamp\": true, \"domain\": [1.6795441592037095, 2.8435303446343494], \"zero\": false}}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse_code 3  \", \"transform\": [{\"filter\": \"(datum['mouse_code'] === '3')\"}], \"width\": 80}], \"data\": {\"name\": \"data-3845748016dffc22c0924000d90c1920\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-3845748016dffc22c0924000d90c1920\": [{\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054}, {\"stim\": 0, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665}, {\"stim\": 0, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208}, {\"stim\": 0, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149}, {\"stim\": 1, \"neuron\": \"0\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294}, {\"stim\": 1, \"neuron\": \"1\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365}, {\"stim\": 1, \"neuron\": \"2\", \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.HConcatChart(...)"
      ]
     },
     "execution_count": 21,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "visualization.facet(fig_trials,column='mouse_code')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "TODO neuron dont work here anymore, only neuron_code"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 45,
   "metadata": {
    "lines_to_next_cell": 2,
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-065b1cca0073456a935b3a7d74486b8d\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-065b1cca0073456a935b3a7d74486b8d\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-065b1cca0073456a935b3a7d74486b8d\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-5b5e1b958fd874572b1b192dd91b47f7\"}, \"facet\": {\"column\": {\"type\": \"quantitative\", \"field\": \"neuron\"}, \"row\": {\"type\": \"nominal\", \"field\": \"mouse\"}}, \"spec\": {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"neuron\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"log_firing_rate\", \"scale\": {\"clamp\": true, \"domain\": [1.6795441592037095, 2.8435303446343494], \"zero\": false}}}, \"height\": 50, \"width\": 50}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-5b5e1b958fd874572b1b192dd91b47f7\": [{\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.9763086274331563, \"Firing rate\": 94.69098352056629, \"firing_rate\": 94.69098352056629, \"i_spike\": 46.5, \"isi\": 0.07445745130995647}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.969655556303467, \"Firing rate\": 93.2514420061473, \"firing_rate\": 93.2514420061473, \"i_spike\": 37.5, \"isi\": 0.08897306675410553}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.531105592695681, \"Firing rate\": 33.97078578167243, \"firing_rate\": 33.97078578167243, \"i_spike\": 35.0, \"isi\": 0.10118859672388851}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8332759022844978, \"Firing rate\": 68.12019810353401, \"firing_rate\": 68.12019810353401, \"i_spike\": 54.0, \"isi\": 0.06495088817497606}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.404965872476311, \"Firing rate\": 254.07730398783858, \"firing_rate\": 254.07730398783858, \"i_spike\": 23.0, \"isi\": 0.14955278647395506}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.682804387378041, \"Firing rate\": 48.17307701287699, \"firing_rate\": 48.17307701287699, \"i_spike\": 42.5, \"isi\": 0.08273886061861176}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8140891600057318, \"Firing rate\": 65.176218612595, \"firing_rate\": 65.176218612595, \"i_spike\": 49.0, \"isi\": 0.070266350677886}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6055976745472256, \"Firing rate\": 40.32716336310376, \"firing_rate\": 40.32716336310376, \"i_spike\": 40.0, \"isi\": 0.08716694241588323}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.6175998238914127, \"Firing rate\": 41.45718636757235, \"firing_rate\": 41.45718636757235, \"i_spike\": 46.5, \"isi\": 0.07561741193998633}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.8959680206741638, \"Firing rate\": 78.69878376184383, \"firing_rate\": 78.69878376184383, \"i_spike\": 39.0, \"isi\": 0.08576764472123868}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9139002442093729, \"Firing rate\": 82.01631343397008, \"firing_rate\": 82.01631343397008, \"i_spike\": 47.5, \"isi\": 0.07331121890269555}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.031339227022029, \"Firing rate\": 107.48286322017817, \"firing_rate\": 107.48286322017817, \"i_spike\": 35.0, \"isi\": 0.0930741447605036}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.9300888159681042, \"Firing rate\": 85.13121191136484, \"firing_rate\": 85.13121191136484, \"i_spike\": 33.5, \"isi\": 0.10382011065966096}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.721540757714671, \"Firing rate\": 526.6726398044871, \"firing_rate\": 526.6726398044871, \"i_spike\": 40.0, \"isi\": 0.0860901656392652}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 1.7082531376367023, \"Firing rate\": 51.08026452450442, \"firing_rate\": 51.08026452450442, \"i_spike\": 39.5, \"isi\": 0.08751496605304387}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8335809054786223, \"Firing rate\": 68.16805543614548, \"firing_rate\": 68.16805543614548, \"i_spike\": 48.5, \"isi\": 0.0711741707058639}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.118053084515938, \"Firing rate\": 131.2360301135069, \"firing_rate\": 131.2360301135069, \"i_spike\": 47.0, \"isi\": 0.07405563176751508}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.709548653526429, \"Firing rate\": 51.232866265833856, \"firing_rate\": 51.232866265833856, \"i_spike\": 49.0, \"isi\": 0.07122053945610679}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.0280928551575155, \"Firing rate\": 106.6824191222689, \"firing_rate\": 106.6824191222689, \"i_spike\": 48.0, \"isi\": 0.07319521272276054}, {\"stim\": 0, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 1.8907967238123642, \"Firing rate\": 77.76724679051476, \"firing_rate\": 77.76724679051476, \"i_spike\": 51.0, \"isi\": 0.06605431732992914}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.310275346647125, \"Firing rate\": 204.30328355186765, \"firing_rate\": 204.30328355186765, \"i_spike\": 63.5, \"isi\": 0.0549006357065612}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.446039330083691, \"Firing rate\": 279.27967478730284, \"firing_rate\": 279.27967478730284, \"i_spike\": 58.5, \"isi\": 0.05931874309677873}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.6920357768491945, \"Firing rate\": 49.20800711938857, \"firing_rate\": 49.20800711938857, \"i_spike\": 50.5, \"isi\": 0.06832789284207057}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.615576884824237, \"Firing rate\": 41.2645282833922, \"firing_rate\": 41.2645282833922, \"i_spike\": 55.0, \"isi\": 0.0626381091069373}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.1543379610667444, \"Firing rate\": 142.6717410549704, \"firing_rate\": 142.6717410549704, \"i_spike\": 50.0, \"isi\": 0.06894357119908716}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.9504267495568781, \"Firing rate\": 89.21271359365508, \"firing_rate\": 89.21271359365508, \"i_spike\": 50.0, \"isi\": 0.06881236296382152}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0634170892692283, \"Firing rate\": 115.72230866857004, \"firing_rate\": 115.72230866857004, \"i_spike\": 61.0, \"isi\": 0.05706789428097184}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.013817646010474, \"Firing rate\": 103.23278551688678, \"firing_rate\": 103.23278551688678, \"i_spike\": 46.0, \"isi\": 0.07596937068566334}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.27528133993426, \"Firing rate\": 188.48697299124024, \"firing_rate\": 188.48697299124024, \"i_spike\": 56.0, \"isi\": 0.06220418480890354}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.7888913876797967, \"Firing rate\": 61.50230429100158, \"firing_rate\": 61.50230429100158, \"i_spike\": 53.0, \"isi\": 0.06463814083356904}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8634255723219744, \"Firing rate\": 73.0172668033884, \"firing_rate\": 73.0172668033884, \"i_spike\": 50.5, \"isi\": 0.06918009869058114}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.257615318742404, \"Firing rate\": 180.97363879659787, \"firing_rate\": 180.97363879659787, \"i_spike\": 58.5, \"isi\": 0.05854809276162012}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.4124343008526785, \"Firing rate\": 258.48437803035006, \"firing_rate\": 258.48437803035006, \"i_spike\": 55.5, \"isi\": 0.06199207554313428}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.713351058538618, \"Firing rate\": 51.68339791574209, \"firing_rate\": 51.68339791574209, \"i_spike\": 51.5, \"isi\": 0.0659435350053342}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 3.195183624743835, \"Firing rate\": 1567.4136506950788, \"firing_rate\": 1567.4136506950788, \"i_spike\": 57.5, \"isi\": 0.060225748261692205}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.187588508253008, \"Firing rate\": 154.02403916544554, \"firing_rate\": 154.02403916544554, \"i_spike\": 57.5, \"isi\": 0.0612557605064473}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.3216643847388303, \"Firing rate\": 209.73184857734805, \"firing_rate\": 209.73184857734805, \"i_spike\": 50.0, \"isi\": 0.06765602636603735}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.7065523982943671, \"Firing rate\": 50.880620418931976, \"firing_rate\": 50.880620418931976, \"i_spike\": 51.5, \"isi\": 0.0664677812649505}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.186377600447997, \"Firing rate\": 153.59518467463442, \"firing_rate\": 153.59518467463442, \"i_spike\": 60.0, \"isi\": 0.058598254644325665}, {\"stim\": 0, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.8912766985979508, \"Firing rate\": 77.85324132409274, \"firing_rate\": 77.85324132409274, \"i_spike\": 52.5, \"isi\": 0.06661633337128367}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.157157740188547, \"Firing rate\": 143.60109124650043, \"firing_rate\": 143.60109124650043, \"i_spike\": 72.5, \"isi\": 0.04748070756013734}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0286084758562937, \"Firing rate\": 106.80915416710721, \"firing_rate\": 106.80915416710721, \"i_spike\": 81.0, \"isi\": 0.042618775265312096}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.917449698939095, \"Firing rate\": 82.6893730144658, \"firing_rate\": 82.6893730144658, \"i_spike\": 70.0, \"isi\": 0.050048774808680176}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.1524772264463157, \"Firing rate\": 142.06177164909278, \"firing_rate\": 142.06177164909278, \"i_spike\": 56.0, \"isi\": 0.06238664882382208}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.35703710239945, \"Firing rate\": 227.5291803905961, \"firing_rate\": 227.5291803905961, \"i_spike\": 79.0, \"isi\": 0.04419106441836823}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.2389102567752044, \"Firing rate\": 173.34457590633153, \"firing_rate\": 173.34457590633153, \"i_spike\": 70.0, \"isi\": 0.049871963245551106}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.257085526586655, \"Firing rate\": 180.7530051911462, \"firing_rate\": 180.7530051911462, \"i_spike\": 76.0, \"isi\": 0.04576395957750786}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.1154823003461525, \"Firing rate\": 130.4614798033695, \"firing_rate\": 130.4614798033695, \"i_spike\": 54.5, \"isi\": 0.06356794250276941}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.132810426921343, \"Firing rate\": 135.77206610915889, \"firing_rate\": 135.77206610915889, \"i_spike\": 68.5, \"isi\": 0.051210363880052484}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.0788512328113344, \"Firing rate\": 119.90884860960239, \"firing_rate\": 119.90884860960239, \"i_spike\": 69.0, \"isi\": 0.05094885503311947}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0909439203043876, \"Firing rate\": 123.29456148136852, \"firing_rate\": 123.29456148136852, \"i_spike\": 72.5, \"isi\": 0.047939831849529914}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.829232100042359, \"Firing rate\": 67.48886121226059, \"firing_rate\": 67.48886121226059, \"i_spike\": 59.5, \"isi\": 0.05796161914213184}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9557608856862903, \"Firing rate\": 90.31520783831714, \"firing_rate\": 90.31520783831714, \"i_spike\": 67.0, \"isi\": 0.051971890260153995}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.9218734957208308, \"Firing rate\": 83.53596534918562, \"firing_rate\": 83.53596534918562, \"i_spike\": 61.0, \"isi\": 0.05732891686102423}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.167463071938757, \"Firing rate\": 147.04933740320243, \"firing_rate\": 147.04933740320243, \"i_spike\": 63.0, \"isi\": 0.055376508881073906}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 3.370172502833953, \"Firing rate\": 2345.1601337067536, \"firing_rate\": 2345.1601337067536, \"i_spike\": 67.5, \"isi\": 0.051793837259056195}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.103472392568675, \"Firing rate\": 126.90314715049684, \"firing_rate\": 126.90314715049684, \"i_spike\": 72.0, \"isi\": 0.04829816301999659}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 1.9570909941473933, \"Firing rate\": 90.59223914754149, \"firing_rate\": 90.59223914754149, \"i_spike\": 63.5, \"isi\": 0.05477120888146417}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.052024930972556, \"Firing rate\": 112.72621655758132, \"firing_rate\": 112.72621655758132, \"i_spike\": 81.5, \"isi\": 0.04298238648750208}, {\"stim\": 0, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.5139716346945584, \"Firing rate\": 326.5665022649098, \"firing_rate\": 326.5665022649098, \"i_spike\": 68.5, \"isi\": 0.050907647105637874}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1101407368469713, \"Firing rate\": 128.86670876447295, \"firing_rate\": 128.86670876447295, \"i_spike\": 40.0, \"isi\": 0.08592262378581567}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5850986443715986, \"Firing rate\": 38.467914701339076, \"firing_rate\": 38.467914701339076, \"i_spike\": 38.5, \"isi\": 0.08793048316062213}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.5923575570554507, \"Firing rate\": 39.11628097680206, \"firing_rate\": 39.11628097680206, \"i_spike\": 35.5, \"isi\": 0.09887727522269801}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 2.1324541243067854, \"Firing rate\": 135.66072206645487, \"firing_rate\": 135.66072206645487, \"i_spike\": 44.5, \"isi\": 0.07782986661059074}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 0, \"neuron_x_mouse\": \"m0bayes0\", \"log_firing_rate\": 1.8549409248649884, \"Firing rate\": 71.60460030544526, \"firing_rate\": 71.60460030544526, \"i_spike\": 45.5, \"isi\": 0.07662767226021318}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2624447217072343, \"Firing rate\": 182.9973167061772, \"firing_rate\": 182.9973167061772, \"i_spike\": 63.0, \"isi\": 0.055192203350093394}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.2616414663843485, \"Firing rate\": 1826.5916431967642, \"firing_rate\": 1826.5916431967642, \"i_spike\": 67.5, \"isi\": 0.04885308575856641}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 3.279216825086155, \"Firing rate\": 1902.0276458342512, \"firing_rate\": 1902.0276458342512, \"i_spike\": 79.5, \"isi\": 0.04317615586126199}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 1.9914220026325338, \"Firing rate\": 98.04422154251186, \"firing_rate\": 98.04422154251186, \"i_spike\": 69.5, \"isi\": 0.047278274131031126}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 3, \"neuron_x_mouse\": \"m1bayes0\", \"log_firing_rate\": 2.2694505301317935, \"Firing rate\": 185.97327116425842, \"firing_rate\": 185.97327116425842, \"i_spike\": 71.0, \"isi\": 0.04885203659418005}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 3.2264709560278004, \"Firing rate\": 1684.4997700341435, \"firing_rate\": 1684.4997700341435, \"i_spike\": 90.5, \"isi\": 0.038200894259861194}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.1789767366295836, \"Firing rate\": 150.9999267543244, \"firing_rate\": 150.9999267543244, \"i_spike\": 94.0, \"isi\": 0.03717813161525954}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.4098029193660175, \"Firing rate\": 256.9229614815267, \"firing_rate\": 256.9229614815267, \"i_spike\": 101.0, \"isi\": 0.033305155504366454}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.2456249413297646, \"Firing rate\": 176.045505282659, \"firing_rate\": 176.045505282659, \"i_spike\": 90.0, \"isi\": 0.038597737013182996}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 6, \"neuron_x_mouse\": \"m2bayes0\", \"log_firing_rate\": 2.339052113316357, \"Firing rate\": 218.29918449877064, \"firing_rate\": 218.29918449877064, \"i_spike\": 91.0, \"isi\": 0.03752924670872711}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4226520637869915, \"Firing rate\": 264.6379135207971, \"firing_rate\": 264.6379135207971, \"i_spike\": 120.5, \"isi\": 0.028919454264406265}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.2235573581610177, \"Firing rate\": 167.32366095894628, \"firing_rate\": 167.32366095894628, \"i_spike\": 122.0, \"isi\": 0.028660359262320446}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.5179296705817533, \"Firing rate\": 329.5563396770157, \"firing_rate\": 329.5563396770157, \"i_spike\": 118.0, \"isi\": 0.02895351367587072}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.521198692300412, \"Firing rate\": 332.0463359747387, \"firing_rate\": 332.0463359747387, \"i_spike\": 118.5, \"isi\": 0.02899204861631149}, {\"stim\": 1, \"neuron\": 0, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 9, \"neuron_x_mouse\": \"m3bayes0\", \"log_firing_rate\": 2.4313250752663826, \"Firing rate\": 269.97594826513557, \"firing_rate\": 269.97594826513557, \"i_spike\": 119.0, \"isi\": 0.029257921928936413}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.0625727896966435, \"Firing rate\": 115.49755475329887, \"firing_rate\": 115.49755475329887, \"i_spike\": 53.0, \"isi\": 0.06579328098787442}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.2584148645436253, \"Firing rate\": 181.3071221719965, \"firing_rate\": 181.3071221719965, \"i_spike\": 42.0, \"isi\": 0.0833701631401077}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 2.145325057928468, \"Firing rate\": 139.74138970561347, \"firing_rate\": 139.74138970561347, \"i_spike\": 53.0, \"isi\": 0.06655292244592287}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9487776755377615, \"Firing rate\": 88.87460336326208, \"firing_rate\": 88.87460336326208, \"i_spike\": 57.0, \"isi\": 0.060244279721479235}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 1, \"neuron_x_mouse\": \"m0bayes1\", \"log_firing_rate\": 1.9555237706153699, \"Firing rate\": 90.26591121405241, \"firing_rate\": 90.26591121405241, \"i_spike\": 57.0, \"isi\": 0.05990741643901749}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 1.8815957339003182, \"Firing rate\": 76.13699534385519, \"firing_rate\": 76.13699534385519, \"i_spike\": 60.5, \"isi\": 0.056648521396196354}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.1813509107857936, \"Firing rate\": 151.82766424554603, \"firing_rate\": 151.82766424554603, \"i_spike\": 69.5, \"isi\": 0.048154662285294705}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2788882339896204, \"Firing rate\": 190.05890989515422, \"firing_rate\": 190.05890989515422, \"i_spike\": 63.5, \"isi\": 0.051483509252274434}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.2391163508463072, \"Firing rate\": 173.42685594645815, \"firing_rate\": 173.42685594645815, \"i_spike\": 80.5, \"isi\": 0.04320268000331656}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 4, \"neuron_x_mouse\": \"m1bayes1\", \"log_firing_rate\": 2.0507485446928717, \"Firing rate\": 112.3954019257613, \"firing_rate\": 112.3954019257613, \"i_spike\": 67.5, \"isi\": 0.04943030571684937}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.102847285053447, \"Firing rate\": 126.72061881847783, \"firing_rate\": 126.72061881847783, \"i_spike\": 86.5, \"isi\": 0.04050577107639119}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.1384249781397724, \"Firing rate\": 137.5387199568104, \"firing_rate\": 137.5387199568104, \"i_spike\": 77.0, \"isi\": 0.04511406214365699}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.267237512574355, \"Firing rate\": 185.02802474812694, \"firing_rate\": 185.02802474812694, \"i_spike\": 78.5, \"isi\": 0.0425608529738783}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 2.0187988292530528, \"Firing rate\": 104.423640354486, \"firing_rate\": 104.423640354486, \"i_spike\": 73.5, \"isi\": 0.047447014467260684}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 7, \"neuron_x_mouse\": \"m2bayes1\", \"log_firing_rate\": 1.8939444836252681, \"Firing rate\": 78.33295024336573, \"firing_rate\": 78.33295024336573, \"i_spike\": 78.5, \"isi\": 0.044494808895399314}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 1.9641145083363916, \"Firing rate\": 92.06922942602431, \"firing_rate\": 92.06922942602431, \"i_spike\": 66.5, \"isi\": 0.05194161833513786}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.1466517066998936, \"Firing rate\": 140.168913409514, \"firing_rate\": 140.168913409514, \"i_spike\": 85.5, \"isi\": 0.04112540263649651}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.0727519576034346, \"Firing rate\": 118.23660677967197, \"firing_rate\": 118.23660677967197, \"i_spike\": 75.0, \"isi\": 0.044801267708188895}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 3.1035639054796462, \"Firing rate\": 1269.2989052517016, \"firing_rate\": 1269.2989052517016, \"i_spike\": 85.0, \"isi\": 0.040899446908518294}, {\"stim\": 1, \"neuron\": 1, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 10, \"neuron_x_mouse\": \"m3bayes1\", \"log_firing_rate\": 2.119576028877931, \"Firing rate\": 131.69704452878315, \"firing_rate\": 131.69704452878315, \"i_spike\": 76.0, \"isi\": 0.04510006530099287}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 0, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9863437754566458, \"Firing rate\": 96.90446215696521, \"firing_rate\": 96.90446215696521, \"i_spike\": 69.0, \"isi\": 0.05067638175620918}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 1, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9460316404650375, \"Firing rate\": 88.31442394275165, \"firing_rate\": 88.31442394275165, \"i_spike\": 70.5, \"isi\": 0.04940064826317427}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 2, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 2.0729653945268187, \"Firing rate\": 118.2947292308295, \"firing_rate\": 118.2947292308295, \"i_spike\": 70.5, \"isi\": 0.04977008472002067}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 3, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9059130938433402, \"Firing rate\": 80.52172939929248, \"firing_rate\": 80.52172939929248, \"i_spike\": 61.0, \"isi\": 0.05757496595712777}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m0bayes\", \"i_trial\": 4, \"mouse_code\": \"0\", \"neuron_code\": 2, \"neuron_x_mouse\": \"m0bayes2\", \"log_firing_rate\": 1.9320948065863557, \"Firing rate\": 85.52533945224663, \"firing_rate\": 85.52533945224663, \"i_spike\": 73.5, \"isi\": 0.04762584775648386}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 0, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.751523274100826, \"Firing rate\": 56.431718262982876, \"firing_rate\": 56.431718262982876, \"i_spike\": 67.5, \"isi\": 0.051872894781108854}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 1, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 1.9913972584834598, \"Firing rate\": 98.03863558223746, \"firing_rate\": 98.03863558223746, \"i_spike\": 64.5, \"isi\": 0.054435936587639205}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 2, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.167882228272578, \"Firing rate\": 147.1913295707225, \"firing_rate\": 147.1913295707225, \"i_spike\": 74.5, \"isi\": 0.046999709682287505}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 3, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.3444584716701278, \"Firing rate\": 221.0336888225328, \"firing_rate\": 221.0336888225328, \"i_spike\": 78.0, \"isi\": 0.04444913224972793}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m1bayes\", \"i_trial\": 4, \"mouse_code\": \"1\", \"neuron_code\": 5, \"neuron_x_mouse\": \"m1bayes2\", \"log_firing_rate\": 2.6049089896416886, \"Firing rate\": 402.63265015050996, \"firing_rate\": 402.63265015050996, \"i_spike\": 66.0, \"isi\": 0.05285163600673219}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 0, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.4551510194179023, \"Firing rate\": 285.20098389055266, \"firing_rate\": 285.20098389055266, \"i_spike\": 77.0, \"isi\": 0.0453099600605313}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 1, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.8298443677477554, \"Firing rate\": 675.8407400663997, \"firing_rate\": 675.8407400663997, \"i_spike\": 63.5, \"isi\": 0.05485214609491356}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 2, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 1.8186641166481425, \"Firing rate\": 65.86642872452384, \"firing_rate\": 65.86642872452384, \"i_spike\": 68.0, \"isi\": 0.05157708359418223}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 3, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.0213529209264043, \"Firing rate\": 105.03956654394096, \"firing_rate\": 105.03956654394096, \"i_spike\": 76.5, \"isi\": 0.04592450322104924}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m2bayes\", \"i_trial\": 4, \"mouse_code\": \"2\", \"neuron_code\": 8, \"neuron_x_mouse\": \"m2bayes2\", \"log_firing_rate\": 2.6242778713128136, \"Firing rate\": 420.9959048167892, \"firing_rate\": 420.9959048167892, \"i_spike\": 64.5, \"isi\": 0.05217413989678105}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 0, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0571074507886924, \"Firing rate\": 114.0531936890822, \"firing_rate\": 114.0531936890822, \"i_spike\": 79.0, \"isi\": 0.04414607899367569}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 1, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.1715116735567372, \"Firing rate\": 148.4265775639139, \"firing_rate\": 148.4265775639139, \"i_spike\": 84.5, \"isi\": 0.039279136596701646}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 2, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.0138312078330864, \"Firing rate\": 103.2360092432828, \"firing_rate\": 103.2360092432828, \"i_spike\": 67.0, \"isi\": 0.05195088887427407}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 3, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.070755051618302, \"Firing rate\": 117.6941973955868, \"firing_rate\": 117.6941973955868, \"i_spike\": 68.5, \"isi\": 0.05109640396525365}, {\"stim\": 1, \"neuron\": 2, \"mouse\": \"m3bayes\", \"i_trial\": 4, \"mouse_code\": \"3\", \"neuron_code\": 11, \"neuron_x_mouse\": \"m3bayes2\", \"log_firing_rate\": 2.4213423325865784, \"Firing rate\": 263.84102930464, \"firing_rate\": 263.84102930464, \"i_spike\": 70.0, \"isi\": 0.04893987686956073}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.FacetChart(...)"
      ]
     },
     "execution_count": 45,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "fig_trials.properties(width=50,height=50).facet(row='mouse',column='neuron')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 32,
   "metadata": {},
   "outputs": [
    {
     "ename": "NameError",
     "evalue": "name 'cposter' is not defined",
     "output_type": "error",
     "traceback": [
      "\u001b[0;31m---------------------------------------------------------------------------\u001b[0m",
      "\u001b[0;31mNameError\u001b[0m                                 Traceback (most recent call last)",
      "\u001b[0;32m<ipython-input-32-087692889460>\u001b[0m in \u001b[0;36m<module>\u001b[0;34m\u001b[0m\n\u001b[1;32m      1\u001b[0m \u001b[0;31m# Resolve scale doesnt work with facets yet:\u001b[0m\u001b[0;34m\u001b[0m\u001b[0;34m\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[1;32m      2\u001b[0m \u001b[0;31m#https://github.com/vega/vega-lite/issues/4373#issuecomment-447726094\u001b[0m\u001b[0;34m\u001b[0m\u001b[0;34m\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0;32m----> 3\u001b[0;31m \u001b[0malt\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mlayer\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mcposter\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mfig_trials\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mdata\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0mdf_both\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mresolve_scale\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0my\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0;34m'independent'\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m.\u001b[0m\u001b[0mfacet\u001b[0m\u001b[0;34m(\u001b[0m\u001b[0mrow\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0;34m'mouse'\u001b[0m\u001b[0;34m,\u001b[0m \u001b[0mcolumn\u001b[0m\u001b[0;34m=\u001b[0m\u001b[0;34m'neuron'\u001b[0m\u001b[0;34m)\u001b[0m\u001b[0;34m\u001b[0m\u001b[0;34m\u001b[0m\u001b[0m\n\u001b[0m",
      "\u001b[0;31mNameError\u001b[0m: name 'cposter' is not defined"
     ]
    }
   ],
   "source": [
    "# Resolve scale doesnt work with facets yet:\n",
    "#https://github.com/vega/vega-lite/issues/4373#issuecomment-447726094\n",
    "# alt.layer(cposter, fig_trials, data=df_both).resolve_scale(y='independent').facet(row='mouse', column='neuron')"
   ]
  }
 ],
 "metadata": {
  "hide_input": false,
  "jupytext": {
   "formats": "ipynb,py:light"
  },
  "kernelspec": {
   "display_name": "PyCharm (jup)",
   "language": "python",
   "name": "pycharm-d5912792"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.5"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
